@@ -1,7 +1,13 @@
 from abc import abstractmethod, ABC
+from enum import Enum
 from typing import Dict
 
 
+class ContainerType(Enum):
+    docker = "docker"
+    singularity = "singularity"
+
+
 class Container(ABC):
     def __init__(
         self,
@@ -28,6 +34,11 @@ class Container(ABC):
             )
             self.internal = internal
 
+    @staticmethod
+    @abstractmethod
+    def get_container_type():
+        pass
+
     @staticmethod
     @abstractmethod
     def test_available_by_getting_version() -> str:
