@@ -12,6 +12,7 @@ from glob import glob
 from typing import Optional, List, Tuple, Union
 from urllib import request, parse
 
+from janis_assistant.data.models.run import RunModel
 from janis_core.utils import first_value
 from janis_core.utils.logger import Logger
 
@@ -28,9 +29,11 @@ from janis_assistant.utils import (
     ProcessLogger,
     find_free_port,
 )
-from janis_assistant.utils.dateutil import DateUtil
+from janis_assistant.utils.dateutils import DateUtil
 from janis_assistant.utils.fileutil import tail
-from .cromwellconfiguration import CromwellConfiguration, DatabaseTypeToUse
+from .cromwellconfiguration import CromwellConfiguration
+from janis_assistant.data.enums.dbtype import DatabaseTypeToUse
+
 from ..engine import Engine, TaskStatus
 
 CROMWELL_RELEASES = (
@@ -112,6 +115,8 @@ class Cromwell(Engine):
         self._start_time = None
 
         self.connectionerrorcount = 0
+        self.metadataerrorcount = 0
+
         self.should_stop = False
 
         if not self.connect_to_instance:
@@ -199,13 +204,12 @@ class Cromwell(Engine):
         ) + min_poll
 
     def start_engine(self, additional_cromwell_options: List[str] = None):
+        from ...data.models.preparedjob import PreparedJob
 
-        from janis_assistant.management.configuration import JanisConfiguration
-
-        jc = JanisConfiguration.manager()
+        job = PreparedJob.instance()
 
         self._start_time = DateUtil.now()
-        self.timeout = jc.cromwell.timeout or 10
+        self.timeout = job.cromwell.timeout or 10
 
         if self.test_connection():
             Logger.info("Engine has already been started")
@@ -229,14 +233,17 @@ class Cromwell(Engine):
                 f.writelines(self.config.output())
 
         Logger.log("Finding cromwell jar")
-        cromwell_loc = self.resolve_jar(self.cromwelljar)
+        cromwell_loc = self.resolve_jar(self.cromwelljar, job.cromwell, job.config_dir)
 
         Logger.info(f"Starting cromwell ({cromwell_loc})...")
         cmd = ["java", "-DLOG_MODE=standard"]
 
-        if jc.cromwell and jc.cromwell.memory:
+        if job.cromwell and job.cromwell.memory_mb:
             cmd.extend(
-                [f"-Xmx{jc.cromwell.memory}M", f"-Xms{max(jc.cromwell.memory//2, 1)}M"]
+                [
+                    f"-Xmx{job.cromwell.memory_mb}M",
+                    f"-Xms{max(job.cromwell.memory_mb//2, 1)}M",
+                ]
             )
 
         # if Logger.CONSOLE_LEVEL == LogLevel.VERBOSE:
@@ -484,26 +491,27 @@ class Cromwell(Engine):
         threading.Timer(time, self.poll_metadata).start()
 
     @staticmethod
-    def resolve_jar(cromwelljar):
-        from janis_assistant.management.configuration import JanisConfiguration
+    def resolve_jar(cromwelljar, janiscromwellconf, configdir):
 
-        man = JanisConfiguration.manager()
-        if not man:
-            raise Exception(
-                f"No configuration was initialised. This is "
-                f"likely an error, and you should raise an issue at {ISSUE_URL}"
-            )
-
-        if cromwelljar and os.path.exists(cromwelljar):
+        if cromwelljar:
+            if not os.path.exists(cromwelljar):
+                raise Exception(
+                    f"Specified cromwell jar '{cromwelljar}' but this didn't exist"
+                )
             return cromwelljar
-        if man.cromwell.jarpath and os.path.exists(man.cromwell.jarpath):
-            return man.cromwell.jarpath
+
+        if (
+            janiscromwellconf
+            and janiscromwellconf.jar
+            and os.path.exists(janiscromwellconf.jar)
+        ):
+            return janiscromwellconf.jar
         fromenv = EnvVariables.cromwelljar.resolve(False)
         if fromenv and os.path.exists(fromenv):
             return fromenv
 
         potentials = list(
-            reversed(sorted(glob(os.path.join(man.configdir, "cromwell-*.jar"))))
+            reversed(sorted(glob(os.path.join(configdir, "cromwell-*.jar"))))
         )
 
         valid_paths = [p for p in potentials if os.path.exists(p)]
@@ -553,7 +561,7 @@ class Cromwell(Engine):
             Logger.info(
                 f"Couldn't find cromwell at any of the usual spots, downloading '{cromwellfilename}' now"
             )
-            cromwelljar = os.path.join(man.configdir, cromwellfilename)
+            cromwelljar = os.path.join(configdir, cromwellfilename)
             request.urlretrieve(cromwellurl, cromwelljar, show_progress)
             Logger.info(f"Downloaded {cromwellfilename}")
 
@@ -655,9 +663,9 @@ class Cromwell(Engine):
     def find_or_generate_config(
         self, identifier, config: CromwellConfiguration, config_path
     ):
-        from janis_assistant.management.configuration import JanisConfiguration
+        from ...data.models.preparedjob import PreparedJob
 
-        jc = JanisConfiguration.manager()
+        job = PreparedJob.instance()
 
         if config:
             self.config = config
@@ -665,12 +673,12 @@ class Cromwell(Engine):
         elif config_path:
             shutil.copyfile(config_path, self.config_path)
 
-        elif jc.cromwell.configpath:
-            shutil.copyfile(jc.cromwell.configpath, self.config_path)
+        elif job and job.cromwell.config_path:
+            shutil.copyfile(job.cromwell.config_path, self.config_path)
 
         else:
             self.config: CromwellConfiguration = (
-                jc.template.template.engine_config(EngineType.cromwell, jc)
+                job.template.template.engine_config(EngineType.cromwell, job)
                 or CromwellConfiguration()
             )
             if not self.config.system:
@@ -689,14 +697,15 @@ class Cromwell(Engine):
                     if not cnf.config.root:
                         cnf.config.root = self.execution_dir
             else:
-                self.config.backend = (
-                    CromwellConfiguration.Backend.with_new_local_exec_dir(
-                        self.execution_dir
-                    )
+                self.config.backend = CromwellConfiguration.Backend.with_new_local_exec_dir(
+                    self.execution_dir
                 )
 
     def raw_metadata(
-        self, identifier, expand_subworkflows=True
+        self,
+        identifier,
+        expand_subworkflows=True,
+        metadata_export_file_path: Optional[str] = None,
     ) -> Optional[CromwellMetadata]:
         url = self.url_metadata(
             identifier=identifier, expand_subworkflows=expand_subworkflows
@@ -716,6 +725,15 @@ class Cromwell(Engine):
             data = r.read()
             jsonobj = json.loads(data.decode(r.info().get_content_charset("utf-8")))
 
+            if metadata_export_file_path:
+                try:
+                    with open(metadata_export_file_path, "w+") as f:
+                        json.dump(jsonobj, f)
+                except Exception as e:
+                    Logger.warn(
+                        f"Couldn't persist Cromwell metadata json to '{metadata_export_file_path}': {repr(e)}"
+                    )
+
             return CromwellMetadata(jsonobj)
 
         except request.HTTPError as e:
@@ -775,7 +793,12 @@ class Cromwell(Engine):
                 Logger.warn("Error connecting to cromwell instance: " + repr(e))
             return None
 
-    def metadata(self, identifier, expand_subworkflows=True) -> Optional[RunModel]:
+    def metadata(
+        self,
+        identifier,
+        expand_subworkflows=True,
+        metadata_export_file_path: Optional[str] = None,
+    ) -> Optional[RunModel]:
         if self.error_message:
             return RunModel(
                 id_=RunModel.DEFAULT_ID,
@@ -787,7 +810,11 @@ class Cromwell(Engine):
                 name=None,
             )
 
-        raw = self.raw_metadata(identifier, expand_subworkflows=expand_subworkflows)
+        raw = self.raw_metadata(
+            identifier,
+            expand_subworkflows=expand_subworkflows,
+            metadata_export_file_path=metadata_export_file_path,
+        )
         return raw.standard() if raw else raw
 
     def terminate_task(self, identifier) -> TaskStatus:
