@@ -18,6 +18,9 @@ import janis_core as j
 from janis_assistant.data.enums import TaskStatus
 
 from janis_assistant.modifiers.base import PipelineModifierBase
+from janis_assistant.modifiers.cwlinputobjectunwrappermodifier import (
+    CwlInputObjectUnwrapperModifier,
+)
 
 from janis_assistant.modifiers.inputchecker import InputChecker
 
@@ -230,13 +233,7 @@ def translate(
         valuesfromrecipe = config.recipes.get_recipe_for_keys(recipes)
         inputsdict.update(valuesfromrecipe)
 
-    inputsdict.update(
-        cascade_inputs(
-            wf=None,
-            inputs=inputs,
-            required_inputs=None,
-        )
-    )
+    inputsdict.update(cascade_inputs(wf=None, inputs=inputs, required_inputs=None,))
 
     if isinstance(toolref, DynamicWorkflow):
         if not inputsdict:
@@ -520,10 +517,7 @@ def run_from_jobfile(
     if not workflow:
         raise Exception("Couldn't find workflow with name: " + str(workflow))
 
-    row = cm.create_task_base(
-        wf=workflow,
-        job=jobfile,
-    )
+    row = cm.create_task_base(wf=workflow, job=jobfile,)
 
     jobfile.execution_dir = row.execution_dir
     jobfile.output_dir = row.output_dir
@@ -670,6 +664,7 @@ def prepare_job(
 
         os.makedirs(cache_dir, exist_ok=True)
         processors = [
+            CwlInputObjectUnwrapperModifier(),
             FileFinderLocatorModifier(cache_dir=cache_dir, source_hints=source_hints),
             InputFileQualifierModifier(),
             InputTransformerModifier(cache_dir=cache_dir),
