@@ -24,6 +24,9 @@ from enum import Enum
 from subprocess import call
 from typing import Optional, List, Dict, Union, Any, Tuple
 
+from janis_assistant.modifiers.cwlinputobjectunwrappermodifier import (
+    CwlInputObjectUnwrapperModifier,
+)
 from janis_assistant.utils.callprogram import collect_output_from_command
 from janis_core import (
     Logger,
@@ -175,8 +178,7 @@ class WorkflowManager:
 
         # let's write out the prepared_submission for
         tm.write_prepared_submission_file(
-            prepared_job=prepared_submission,
-            output_dir=tm.execution_dir,
+            prepared_job=prepared_submission, output_dir=tm.execution_dir,
         )
 
         tm.database.submissions.insert_or_update_many(
@@ -325,7 +327,9 @@ class WorkflowManager:
             )
             Logger.info("Submitted detatched engine")
         except Exception as e:
-            self.set_status(TaskStatus.FAILED)
+            m = f"There was an error submitting the janis workflow, {e}"
+            Logger.critical(m)
+            self.set_status(TaskStatus.FAILED, error=m)
 
         if watch:
             Logger.log("Watching submitted workflow")
@@ -1075,9 +1079,7 @@ Kind regards,
 
     @staticmethod
     def write_prepared_submission_file(
-        prepared_job: PreparedJob,
-        output_dir: str,
-        force_write=False,
+        prepared_job: PreparedJob, output_dir: str, force_write=False,
     ):
         import ruamel.yaml
 
@@ -1166,7 +1168,7 @@ janis run \\
             container_override=container_override,
         )
 
-        modifiers = []
+        modifiers = [CwlInputObjectUnwrapperModifier()]
         if validation:
             modifiers.append(ValidatorPipelineModifier(validation))
 
